@@ -94,7 +94,7 @@ adjustOrDelete    :: Ord k => (a -> Maybe a) -> k -> FM k a -> FM k a
 adjustOrDeleteAll :: Ord k => (a -> Maybe a) -> k -> FM k a -> FM k a
 strict            :: Ord k => FM k a -> FM k a
 strictWith        :: Ord k => (a -> b) -> FM k a -> FM k a
-map               :: (Ord k,Functor (FM k)) => (a -> b) -> FM k a -> FM k b
+map               :: Ord k => (a -> b) -> FM k a -> FM k b
 fold              :: Ord k => (a -> b -> b) -> b -> FM k a -> b
 fold1             :: Ord k => (a -> a -> a) -> FM k a -> a
 fold'             :: Ord k => (a -> b -> b) -> b -> FM k a -> b
@@ -211,10 +211,10 @@ adjustOrInsert     = adjustOrInsertUsingMember
 adjustAllOrInsert  = adjustOrInsertUsingMember
 adjustOrDelete     = DM.update
 adjustOrDeleteAll  = DM.update
-strict xs          = DM.fold (flip const) () xs `seq` xs
-strictWith f xs    = DM.fold (\x z -> f x `seq` z) () xs `seq` xs
+strict xs          = DM.foldr (flip const) () xs `seq` xs
+strictWith f xs    = DM.foldr (\x z -> f x `seq` z) () xs `seq` xs
 map                = fmap
-fold               = DM.fold
+fold               = DM.foldr
 fold' f x xs       = L.foldl' (flip f) x (DM.elems xs)
 fold1  f xs        = L.foldr1 f (DM.elems xs)
 fold1' f xs        = L.foldl1' (flip f) (DM.elems xs)
@@ -277,7 +277,7 @@ sameMap            = A.sameMap
 toSeq              = toSeqUsingFoldWithKey
 keys               = keysUsingFoldWithKey
 mapWithKey         = DM.mapWithKey
-foldWithKey        = DM.foldWithKey
+foldWithKey        = DM.foldrWithKey
 foldWithKey' f x m = L.foldl' (\b (k,a) -> f k a b) x (DM.toList m)
 filterWithKey      = DM.filterWithKey
 partitionWithKey   = DM.partitionWithKey
@@ -290,7 +290,7 @@ maxViewWithKey m   = if DM.null m
                         then fail (moduleName ++ ".maxViewWithKey: failed")
                         else return (DM.deleteFindMax m)
 maxElemWithKey     = DM.findMax
-foldrWithKey        = DM.foldWithKey
+foldrWithKey        = DM.foldrWithKey
 foldrWithKey' f x m = L.foldr' (\(k,a) b -> f k a b) x (DM.toAscList m)
 foldlWithKey  f x m = L.foldl  (\b (k,a) -> f b k a) x (DM.toAscList m)
 foldlWithKey' f x m = L.foldl' (\b (k,a) -> f b k a) x (DM.toAscList m)
