@@ -75,6 +75,7 @@ import qualified Control.Applicative as App
 import Control.Monad.Identity
 import Data.Maybe
 import Data.Monoid
+import Data.Semigroup as SG
 import Test.QuickCheck
 
 
@@ -560,6 +561,8 @@ instance Arbitrary a => Arbitrary (Seq a) where
 instance CoArbitrary a => CoArbitrary (Seq a) where
   coarbitrary xs = coarbitrary (toList xs)
 
+instance Semigroup (Seq a) where
+  (<>) = append
 instance Monoid (Seq a) where
   mempty  = empty
-  mappend = append
+  mappend = (SG.<>)
